// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//  Giuseppe Vacanti (cosine science & computing bv)
//  March  3, 2003
// 
//   $Id: TimeRows.h,v 1.2 2003/08/26 14:46:43 gvacanti Exp $

#ifndef TIME_ROWS_H
#define TIME_ROWS_H

#include<vector>
#include<DataFilter.h>
#include<SmartDal>

class STime;


// Given a table with a TIME column (like any of the XMM-Newton
// housekeeping sets) provides an interface to access row ranges based
// on time comparisons.

class TimeRows : private std::vector<std::pair<unsigned long, STime> > {
public:
  TimeRows(const SmartDal::TableH & tab);
  TimeRows(const SmartDal::TableH & tab,
	   const std::vector<DataFilter::RowRange>& ranges);
  const_iterator lower_bound(const STime & time) const;
  const_iterator upper_bound(const STime & time) const;
  const_iterator begin() const;
  const_iterator end() const;
  const_iterator active_record(const STime & time) const;
  unsigned index(const_iterator i) const;
  STime totime(const_iterator i) const;
  std::pair<long, long> active_range(const STime & time) const;
  //  STime operator[](size_t index) const;

  typedef std::vector<std::pair<unsigned long, STime> >::const_iterator const_iterator;
  
 private:
  typedef  std::vector<std::pair<unsigned long, STime> >::const_iterator XX;

};


#endif
