// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine) 
// August 2001
//

#include <Observation.h>

#include <iostream>
#include<iterator>
#include <string>
#include <map>
#include <cassert>


int main() {

  std::map<Xmm::Instrument, std::string> nicknames, configurations;

  // These are the nicknames and configuration names taken from the
  // Observation::Instrument 's constructor.
  nicknames[Xmm::EMOS1] = "M1";
  nicknames[Xmm::EMOS2] = "M2";
  nicknames[Xmm::RGS1] = "R1";
  nicknames[Xmm::RGS2] = "R2";
  nicknames[Xmm::EPN] = "PN";
  nicknames[Xmm::OM] = "OM";

  configurations[Xmm::EMOS1] = "EPIC MOS";
  configurations[Xmm::EMOS2] = "EPIC MOS";
  configurations[Xmm::RGS1] = "RGS";
  configurations[Xmm::RGS2] = "RGS";
  configurations[Xmm::EPN] = "EPIC PN";
  configurations[Xmm::OM] = "OM";



  typedef std::vector<XmmInstrument *>::const_iterator VI;
  for(VI i = xmmPayLoad.instruments().begin();
      i != xmmPayLoad.instruments().end();
      ++i){
    OdfIngest::Instrument oi(*i);
    if(oi.identifier() == Xmm::ERM) continue;
    std::cout << "name " << oi.name() << std::endl
	      << "nickname " << oi.nickname() << std::endl
	      << "configuration " << oi.configuration() << std::endl
	      << "identifier " << oi.identifier() << std::endl;

    OdfIngest::Instrument oii(oi.nickname());
    assert(oi.identifier() == oii.identifier());
    std::cout << "Construction via nickname ok" << std::endl;

    const OdfIngest::DataModes & dm = oi.science_data_modes();
    std::copy(dm.begin(), dm.end(),
	      std::ostream_iterator<OdfIngest::DataMode>(std::cout, "\n"));
    
    std::cout << oi << std::endl;
    std::cout << std::string(72, '-') << std::endl;
    
    assert(oi.nickname() == nicknames[oi.identifier()]);
    assert(oi.configuration() == configurations[oi.identifier()]);    
  }
}
