// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// A class to manage ODF constituent information.
//
// 1998, Giuseppe Vacanti (XMM-SOC ESA)

/*
  The class is based on the ODF file name convention described in the
  ODF ICD. Some details of that convention can b found in the class
  implementation code.
*/

// Time-stamp: < Giuseppe Vacanti -- 2000 June 16 >

#ifndef OdfConstituent_H
#define OdfConstituent_H

#include <string>
#include <ExposureObject.h>
#include <STime.h>

// FIXME 2000-09-19: it should be implemented in terms of OdfSet

class OdfConstituent {
  
 public:

  enum FileType {science, auxiliary, housekeeping, spacecraft, summary};

  OdfConstituent();
  OdfConstituent(const string& fname);
  
  string name() const;
  string revolution() const;
  string observation() const;
  string proposal() const;
  string proposal_exposure() const;
  string instrument() const;
  string scheduled() const;
  string exposure() const;
  string long_exposure() const;
  string ccd() const;
  string data() const;
  string type() const;
  string base_name() const;
  string dir_name() const;
  
  bool is_slew() const;

  FileType file_type() const;
  
 private:
  
  string _name;
  
};

#endif
